# sem_search
 
This is designed to allow for rapid semantic search. It utilises Faiss to create an index for rapid search through embeddings. The library provides useful functions to preprocess data, create an index, retrieve data about datapoints corresponding to that index and search.

It draws inspiration and code from Mathew Alexander's implementation [here](https://towardsdatascience.com/billion-scale-semantic-similarity-search-with-faiss-sbert-c845614962e2):